'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _swPrecache = require('sw-precache');

var _swPrecache2 = _interopRequireDefault(_swPrecache);

var _constants = require('./constants');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const generateSWPrecacheConfig = ({
  root,
  publicDir,
  logger
}, extraSWPrecacheConfig) => {
  const hexoPublicDir = publicDir;
  const rootPrefix = root.replace(/\/$/, '');
  return Object.assign({
    logger,
    replacePrefix: rootPrefix,
    staticFileGlobs: [hexoPublicDir + '/**/*.{js,html,css,png,jpg,gif,svg,eot,ttf,woff}'],
    stripPrefix: hexoPublicDir
  }, extraSWPrecacheConfig);
};

const runSWPrecache = function runSWPrecache() {
  const publicDir = this.public_dir,
        config = this.config,
        log = this.log;
  const root = config.root,
        offline = config.offline;

  // early return when no index.html presets in public directory

  const indexHTMLPath = _path2.default.join(publicDir, 'index.html');
  if (!_fs2.default.existsSync(indexHTMLPath)) {
    return Promise.resolve();
  }

  const SWPrecacheConfig = generateSWPrecacheConfig({ root, publicDir, logger: log.info.bind(log) }, offline);

  return _swPrecache2.default.write(_path2.default.join(publicDir, _constants.workerName), SWPrecacheConfig);
};

exports.default = runSWPrecache;